@@ -6,12 +6,18 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Ni volis sciigi vin, ke %s publikigis la kalendaron „%s“.",
     "Open »%s«" : "Malfermi „%s“",
     "Cheers!" : "Ĝis!",
+    "Upcoming events" : "Venontaj eventoj",
+    "No more events today" : "Ne plu eventoj hodiaŭ",
+    "No upcoming events" : "Neniuj venontaj eventoj",
+    "More events" : "Pliaj eventoj",
     "Calendar" : "Kalendaro",
+    "New booking {booking}" : "Nova rezervo {booking}",
     "Confirm" : "Konfirmi",
+    "Description:" : "Priskribo:",
     "Date:" : "Dato:",
     "Where:" : "Kie:",
+    "Comment:" : "Komento:",
     "A Calendar app for Nextcloud" : "Aplikaĵo pri kalendaro por Nextcloud",
-    "New event" : "Nova okazaĵo",
     "Today" : "Hodiaŭ",
     "Day" : "Tago",
     "Week" : "Semajno",
@@ -20,6 +26,7 @@ OC.L10N.register(
     "Copy link" : "Kopii ligilon",
     "Edit" : "Modifi",
     "Delete" : "Forigi",
+    "Create new" : "Krei nove",
     "New calendar" : "Nova kalendaro",
     "Export" : "Eksporti",
     "Calendar link copied to clipboard." : "Kalendara ligilo kopiita al tondujo",
@@ -28,6 +35,9 @@ OC.L10N.register(
     "Deleted" : "Forigita",
     "Restore" : "Restaŭri",
     "Delete permanently" : "Forigi por ĉiam",
+    "Empty trash bin" : "Malpleni rubujon",
+    "Deck" : "Kartaro",
+    "Hidden" : "Nevidebla",
     "Internal link" : "Interna ligilo",
     "Share link" : "Kunhavigi ligilon",
     "Delete share link" : "Forigi kunhavo-ligilon",
@@ -38,53 +48,86 @@ OC.L10N.register(
     "Filename" : "Dosiernomo",
     "Cancel" : "Nuligi",
     "Automatic" : "Aŭtomata",
+    "or" : "aŭ",
+    "Previous period" : "Antaŭa periodo",
     "List view" : "Lista vido",
     "Actions" : "Agoj",
+    "Editor" : "Redaktilo",
+    "Close editor" : "Fermi redaktilon",
+    "Enable birthday calendar" : "Ebligi naskiĝtaga kalendaro",
+    "Show tasks in calendar" : "Montri taskojn en la kalendaro",
+    "Enable simplified editor" : "Ebligi simpligitan redaktilon",
+    "Show weekends" : "Montri semajnfinojn",
     "Show week numbers" : "Montri numerojn de semajno",
+    "Show keyboard shortcuts" : "Montri klavarajn ŝparvojojn",
     "Location" : "Loko",
     "Description" : "Priskribo",
     "to" : "al",
     "Add" : "Aldoni",
-    "Monday" : "lundo",
-    "Tuesday" : "mardo",
-    "Wednesday" : "merkredo",
-    "Thursday" : "ĵaŭdo",
-    "Friday" : "vendredo",
-    "Saturday" : "sabato",
-    "Sunday" : "dimanĉo",
+    "Monday" : "Lundo",
+    "Tuesday" : "Mardo",
+    "Wednesday" : "Merkredo",
+    "Thursday" : "Ĵaŭdo",
+    "Friday" : "Vendredo",
+    "Saturday" : "Sabato",
+    "Sunday" : "Dimanĉo",
+    "Before the event" : "Antaŭe la evento",
+    "After the event" : "Post la evento",
     "Update" : "Ĝisdatigi",
+    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Ni sendis al vi retmesaĝon kun detaloj. Bonvolu konfirmi vian rendevuon per la ligilo en la retpoŝto. Vi povas fermi ĉi tiun paĝon nun.",
     "Your email address" : "Via retpoŝta adreso",
     "Notification" : "Atentigo",
     "Email" : "Retpoŝto",
+    "_second_::_seconds_" : ["sekundo","sekundoj"],
+    "_minute_::_minutes_" : ["minuto","minutoj"],
+    "_hour_::_hours_" : ["horo","horoj"],
+    "_day_::_days_" : ["tago","tagoj"],
+    "_week_::_weeks_" : ["semajno","semajnoj"],
     "Delete file" : "Forigi dosieron",
     "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
-    "Available" : "Disponeblaj",
+    "Available" : "Disponeble",
+    "Not available" : "Ne disponeble",
+    "Done" : "Farita",
     "Busy" : "Okupita",
+    "Out of office" : "Ekstere oficejo",
     "Unknown" : "Nekonata",
     "Accept" : "Akcepti",
     "Decline" : "Malakcepti",
     "Tentative" : "Nekonfirmita",
-    "Send email" : "Sendi retpoŝtmesaĝon",
+    "Attendees" : "Ĉeestontoj",
+    "Required participant" : "Bezonata partoprenanto",
+    "Optional participant" : "Laŭvola partoprenanto",
+    "Remove group" : "Forigi grupon",
+    "From" : "De",
+    "To" : "Al",
     "All day" : "Tuttage",
     "Repeat" : "Ripeti",
     "never" : "neniam",
     "after" : "post",
-    "More" : "Pli",
+    "first" : "Una",
+    "third" : "Tria",
+    "fourth" : "Kvara",
+    "fifth" : "Kvina",
+    "last" : "Lasta",
+    "By day of the month" : "Per tago de la monato",
+    "On the" : "Je la",
+    "_month_::_months_" : ["Monato","Monatoj"],
+    "_year_::_years_" : ["Jaro","Jaroj"],
+    "weekday" : "Semajntago",
+    "weekend day" : "Semajnfintago",
+    "on {formattedDate}" : "je la {formattedDate}",
     "Global" : "Monda",
     "Subscribe" : "Aboni",
+    "Time:" : "Tempo:",
     "Personal" : "Persona",
-    "[Today]" : "[Hodiaŭ]",
-    "[Tomorrow]" : "[Morgaŭ]",
-    "[Yesterday]" : "[Hieraŭ]",
     "Details" : "Detaloj",
-    "Attendees" : "Ĉeestontoj",
     "Resources" : "Rimedoj",
     "Close" : "Fermi",
+    "Untitled event" : "Sentitola okazaĵo",
     "Anniversary" : "Datreveno",
     "Week {number} of {year}" : "Semajno {number} en {year}",
     "Daily" : "Ĉiutage",
     "Weekly" : "Ĉiusemajne",
-    "Untitled event" : "Sentitola okazaĵo",
     "Other" : "Alia",
     "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
     "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
@@ -94,9 +137,9 @@ OC.L10N.register(
     "Canceled" : "Nuligita",
     "Categories" : "Kategorioj",
     "Add this as a new category" : "Aldoni tion kiel novan kategorion",
-    "Talk" : "Paroli",
-    "Mail" : "Retpoŝtilo",
-    "Birthday" : "Naskiĝotago",
-    "User not found" : "Netrovita uzanto"
+    "User not found" : "Netrovita uzanto",
+    "[Today]" : "[Hodiaŭ]",
+    "[Tomorrow]" : "[Morgaŭ]",
+    "[Yesterday]" : "[Hieraŭ]"
 },
 "nplurals=2; plural=(n != 1);");
